[−][src]Module substrate_subxt::contracts
Implements support for the pallet_contracts module.
Structs
| CallCall | Makes a call to an account, optionally transferring some balance. |
| CodeStoredEvent | Code stored event. |
| InstantiateCall | Creates a new contract from the |
| InstantiatedEvent | Instantiated event. |
| PutCodeCall | Stores the given binary Wasm code into the chain's storage and returns
its |
Traits
| CallCallEventsSubscriber | Call extension trait. |
| CallCallXtBuilder | Call extension trait. |
| CodeStoredEventExt | Event extension trait. |
| Contracts | The subset of the |
| ContractsEventsDecoder |
|
| InstantiateCallEventsSubscriber | Call extension trait. |
| InstantiateCallXtBuilder | Call extension trait. |
| InstantiatedEventExt | Event extension trait. |
| PutCodeCallEventsSubscriber | Call extension trait. |
| PutCodeCallXtBuilder | Call extension trait. |
Type Definitions
| Gas | Gas units are chosen to be represented by u64 so that gas metering instructions can operate on them efficiently. |