[][src]Struct substrate_subxt::CheckVersion

pub struct CheckVersion<T: System>(pub PhantomData<T>, pub u32);

SignedExtra checks copied from substrate, in order to remove requirement to implement substrate's frame_system::Trait Ensure the runtime version registered in the transaction is the same as at present.

Note

This is modified from the substrate version to allow passing in of the version, which is returned via additional_signed().