[][src]Struct substrate_subxt::Client

pub struct Client<T: System, S = MultiSignature, E = DefaultExtra<T>> { /* fields omitted */ }

Client to interface with a substrate node.

Implementations

impl<T: System, S, E> Client<T, S, E>[src]

pub fn metadata(&self) -> &Metadata[src]

Returns the chain metadata.

pub async fn fetch<'_, F: Store<T>>(
    &'_ self,
    store: F,
    hash: Option<T::Hash>
) -> Result<F::Returns, Error>
[src]

Fetch a StorageKey.

pub async fn query_storage<'_>(
    &'_ self,
    keys: Vec<StorageKey>,
    from: T::Hash,
    to: Option<T::Hash>
) -> Result<Vec<StorageChangeSet<<T as System>::Hash>>, Error>
[src]

Query historical storage entries

pub async fn header<'_, H>(
    &'_ self,
    hash: Option<H>
) -> Result<Option<T::Header>, Error> where
    H: Into<T::Hash> + 'static, 
[src]

Get a header

pub async fn block_hash<'_>(
    &'_ self,
    block_number: Option<BlockNumber<T>>
) -> Result<Option<T::Hash>, Error>
[src]

Get a block hash. By default returns the latest block hash

pub async fn finalized_head<'_>(&'_ self) -> Result<T::Hash, Error>[src]

Get a block hash of the latest finalized block

pub async fn block<'_, H>(
    &'_ self,
    hash: Option<H>
) -> Result<Option<SignedBlock<Block<<T as System>::Header, <T as System>::Extrinsic>>>, Error> where
    H: Into<T::Hash> + 'static, 
[src]

Get a block

pub async fn read_proof<'_, H>(
    &'_ self,
    keys: Vec<StorageKey>,
    hash: Option<H>
) -> Result<ReadProof<T::Hash>, Error> where
    H: Into<T::Hash> + 'static, 
[src]

Get proof of storage entries at a specific block's state.

pub async fn submit_extrinsic<'_, X: Encode>(
    &'_ self,
    extrinsic: X
) -> Result<T::Hash, Error>
[src]

Create and submit an extrinsic and return corresponding Hash if successful

pub async fn submit_and_watch_extrinsic<X: Encode + 'static>(
    self,
    extrinsic: X,
    decoder: EventsDecoder<T>
) -> Result<ExtrinsicSuccess<T>, Error>
[src]

Create and submit an extrinsic and return corresponding Event if successful

pub async fn subscribe_events<'_>(
    &'_ self
) -> Result<Subscription<StorageChangeSet<T::Hash>>, Error>
[src]

Subscribe to events.

pub async fn subscribe_blocks<'_>(
    &'_ self
) -> Result<Subscription<T::Header>, Error>
[src]

Subscribe to new blocks.

pub async fn subscribe_finalized_blocks<'_>(
    &'_ self
) -> Result<Subscription<T::Header>, Error>
[src]

Subscribe to finalized blocks.

impl<T, S, E> Client<T, S, E> where
    T: System + Balances + Send + Sync + 'static,
    S: 'static,
    E: SignedExtra<T> + SignedExtension + 'static, 
[src]

pub async fn create_raw_payload<'_, '_, C: Call<T>>(
    &'_ self,
    account_id: &'_ <T as System>::AccountId,
    call: C
) -> Result<SignedPayload<Encoded, <E as SignedExtra<T>>::Extra>, Error>
[src]

Creates raw payload to be signed for the supplied Call without private key

pub async fn xt<'_, P>(
    &'_ self,
    signer: P,
    nonce: Option<T::Index>
) -> Result<XtBuilder<T, P, S, E>, Error> where
    P: Pair,
    P::Signature: Codec,
    S: Verify,
    S::Signer: From<P::Public> + IdentifyAccount<AccountId = T::AccountId>, 
[src]

Create a transaction builder for a private key.