[][src]Struct substrate_subxt::XtBuilder

pub struct XtBuilder<T: System, P, S, E> { /* fields omitted */ }

Transaction builder.

Implementations

impl<T: System, P, S, E> XtBuilder<T, P, S, E>[src]

pub fn metadata(&self) -> &Metadata[src]

Returns the chain metadata.

pub fn nonce(&self) -> T::Index[src]

Returns the nonce.

pub fn set_nonce(&mut self, nonce: T::Index) -> &mut XtBuilder<T, P, S, E>[src]

Sets the nonce to a new value.

pub fn increment_nonce(&mut self) -> &mut XtBuilder<T, P, S, E>[src]

Increment the nonce

impl<T: System + Send + Sync + 'static, P, S: 'static, E> XtBuilder<T, P, S, E> where
    P: Pair,
    S: Verify + Codec + From<P::Signature>,
    S::Signer: From<P::Public> + IdentifyAccount<AccountId = T::AccountId>,
    T::Address: From<T::AccountId>,
    E: SignedExtra<T> + SignedExtension + 'static, 
[src]

pub fn create_and_sign<C: Call<T>>(
    &self,
    call: C
) -> Result<UncheckedExtrinsic<T::Address, Encoded, S, <E as SignedExtra<T>>::Extra>, Error>
[src]

Creates and signs an Extrinsic for the supplied Call

pub async fn submit<'_, C: Call<T>>(&'_ self, call: C) -> Result<T::Hash, Error>[src]

Submits a transaction to the chain.

pub fn watch(self) -> EventsSubscriber<T, P, S, E>[src]

Submits transaction to the chain and watch for events.